#ifndef EVENTSHPP
#define EVENTSHPP

#include <bios.h>
#include <stdio.h>
#include <stdlib.h>
#include <time.h>
#include <dos.h>

#include "mouse.hpp"
#include "icon.hpp"
#include "screen.hpp"
#include "graphics.hpp"
#include "constant.hpp"
#include "database.hpp"
#include "delay.hpp"

#if ZORTECH
#include <int.h>
#define enable() int_on()
#define disable() int_off()
#endif

// setup some IBM PC constants

// the PC's timer chip frequency in Hz
#define TIMER_CLOCK 		1193280

// timer chip commands and ports
#define TIMER_SET_COMMAND 	0xB6
#define TIMER_COMMAND_PORT 	0x43
#define TIMER_DATA_PORT 	0x42
#define TIMER_CONTROL_PORT 	0x61

// standard frequencies and delays
#define ONE_KILOHERTZ		1000
#define BEEPER_DELAY		30

class Events {

	Mouse mouse;
	Delay delay;

public:

	Events();

	// mouse functions
	void ShowMouseCursor() {mouse. Show(); }
	void HideMouseCursor() {mouse. Hide(); }
	void ProcessMouseActions();

	// keyboard functions
	int GetKeyPressed();
	int AnyKeysPressed();
	void ProcessUserKeys();

	// DOS time functions
	long SystemTime();
	char* CurrentTime(float = 0);

	void Wait(long period) {delay. Wait(period);}

	// sound functions
	void Beep();
	void SoundOn(int frequency = ONE_KILOHERTZ, 
		     unsigned int duration = 0);
	void SoundOff();

	void DisableInterrupts() {disable(); }
	void EnableInterrupts() {enable(); }
};

extern Events* EventsHandler;

#endif

